==> zio-aws-backupgateway_2.12-6.20.83.1-sources.jar: zio/aws/backupgateway/model/PutBandwidthRateLimitScheduleResponse.scala <==
package zio.aws.backupgateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.backupgateway.model.primitives.GatewayArn
import scala.jdk.CollectionConverters._
final case class PutBandwidthRateLimitScheduleResponse(
    gatewayArn: Optional[GatewayArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backupgateway.model.PutBandwidthRateLimitScheduleResponse = {
    import PutBandwidthRateLimitScheduleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backupgateway.model.PutBandwidthRateLimitScheduleResponse
      .builder()
      .optionallyWith(
        gatewayArn.map(value => GatewayArn.unwrap(value): java.lang.String)
      )(_.gatewayArn)
      .build()
  }
  def asReadOnly
      : zio.aws.backupgateway.model.PutBandwidthRateLimitScheduleResponse.ReadOnly =
    zio.aws.backupgateway.model.PutBandwidthRateLimitScheduleResponse
      .wrap(buildAwsValue())
}
object PutBandwidthRateLimitScheduleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backupgateway.model.PutBandwidthRateLimitScheduleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.backupgateway.model.PutBandwidthRateLimitScheduleResponse =
      zio.aws.backupgateway.model
        .PutBandwidthRateLimitScheduleResponse(gatewayArn.map(value => value))
    def gatewayArn: Optional[GatewayArn]
    def getGatewayArn: ZIO[Any, AwsError, GatewayArn] =
      AwsError.unwrapOptionField("gatewayArn", gatewayArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backupgateway.model.PutBandwidthRateLimitScheduleResponse
  ) extends zio.aws.backupgateway.model.PutBandwidthRateLimitScheduleResponse.ReadOnly {
    override val gatewayArn: Optional[GatewayArn] = zio.aws.core.internal
      .optionalFromNullable(impl.gatewayArn())
      .map(value => zio.aws.backupgateway.model.primitives.GatewayArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.backupgateway.model.PutBandwidthRateLimitScheduleResponse
  ): zio.aws.backupgateway.model.PutBandwidthRateLimitScheduleResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-backupgateway_3-5.19.7.3-sources.jar: zio/aws/backupgateway/model/PutBandwidthRateLimitScheduleResponse.scala <==
package zio.aws.backupgateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.backupgateway.model.primitives.GatewayArn
import scala.jdk.CollectionConverters.*
final case class PutBandwidthRateLimitScheduleResponse(
    gatewayArn: Optional[GatewayArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backupgateway.model.PutBandwidthRateLimitScheduleResponse = {
    import PutBandwidthRateLimitScheduleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backupgateway.model.PutBandwidthRateLimitScheduleResponse
      .builder()
      .optionallyWith(
        gatewayArn.map(value => GatewayArn.unwrap(value): java.lang.String)
      )(_.gatewayArn)
      .build()
  }
  def asReadOnly
      : zio.aws.backupgateway.model.PutBandwidthRateLimitScheduleResponse.ReadOnly =
    zio.aws.backupgateway.model.PutBandwidthRateLimitScheduleResponse
      .wrap(buildAwsValue())
}
object PutBandwidthRateLimitScheduleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backupgateway.model.PutBandwidthRateLimitScheduleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.backupgateway.model.PutBandwidthRateLimitScheduleResponse =
      zio.aws.backupgateway.model
        .PutBandwidthRateLimitScheduleResponse(gatewayArn.map(value => value))
    def gatewayArn: Optional[GatewayArn]
    def getGatewayArn: ZIO[Any, AwsError, GatewayArn] =
      AwsError.unwrapOptionField("gatewayArn", gatewayArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backupgateway.model.PutBandwidthRateLimitScheduleResponse
  ) extends zio.aws.backupgateway.model.PutBandwidthRateLimitScheduleResponse.ReadOnly {
    override val gatewayArn: Optional[GatewayArn] = zio.aws.core.internal
      .optionalFromNullable(impl.gatewayArn())
      .map(value => zio.aws.backupgateway.model.primitives.GatewayArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.backupgateway.model.PutBandwidthRateLimitScheduleResponse
  ): zio.aws.backupgateway.model.PutBandwidthRateLimitScheduleResponse.ReadOnly =
    new Wrapper(impl)
}
